@@ -49,11 +49,6 @@ gemini <- function(prompt, model = "2.0-flash", temperature = 1, maxOutputTokens
     seed = seed
   )
 
-  # Add responseModalities only for image generation model
-  if (model == "2.0-flash-exp-image-generation") {
-    generation_config$responseModalities <- list("Text", "Image")
-  }
-
   # Create request body as a separate list
   request_body <- list(
     contents = list(
@@ -104,22 +99,26 @@ gemini <- function(prompt, model = "2.0-flash", temperature = 1, maxOutputTokens
 #' @param seed The seed to use. Default is 1234 value should be integer
 #'              see https://ai.google.dev/gemini-api/docs/models/generative-models#model-parameters
 #' @param timeout Request timeout in seconds. Default is 60.
+#' @param labels (Optional) A named list for custom metadata labels.
+#'               Example: \code{list(team = "research", env = "test")}.
 #'
 #' @examples
 #' \dontrun{
 #' # token should be created before this. using the token.vertex() function
 #' prompt <- "What is sachins Jersey number?"
 #' gemini.vertex(prompt, tokens)
+#' gemini.vertex(prompt, tokens, labels = list(team = "research", env = "test"))
 #' }
 #'
 #' @seealso https://ai.google.dev/docs/gemini_api_overview#text_input
 #' @return A character string containing the generated text.
 #' @importFrom httr2 request req_headers req_body_json req_perform resp_body_json req_timeout
+#' @importFrom cli cli_status_clear cli_status cli_alert_info cli_alert_danger
 #'
 #' @export
 
 gemini.vertex <- function(prompt = NULL, tokens = NULL, temperature = 1, maxOutputTokens = 8192,
-                          topK = 40, topP = 0.95, seed = 1234, timeout = 60) {
+                          topK = 40, topP = 0.95, seed = 1234, timeout = 60, labels = NULL) {
   # Validate all parameters at once
   if (!validate_params(prompt, NULL, temperature, topP, topK, seed, api_key = FALSE, tokens = tokens)) {
     return(NULL)
@@ -149,6 +148,19 @@ gemini.vertex <- function(prompt = NULL, tokens = NULL, temperature = 1, maxOutp
     generationConfig = generation_config
   )
 
+  # Check labels format: must be a named list (key-value pairs)
+  if (!is.null(labels)) {
+    # Check if labels is a named list with all names non-empty
+    if (!(is.list(labels) && !is.null(names(labels)) && all(nzchar(names(labels))))) {
+      cli_alert_info("labels must be a named list with key-value pairs. Example: list(team = 'research', env = 'test')")
+      cli_status_clear(id = sb)
+      return(NULL)
+    } else {
+      # Add labels directly to request body
+      request_body$labels <- labels
+    }
+  }
+
   # Add req_timeout to set timeout
   req <- request(tokens$url) |>
     req_headers(
